'''OpenGL extension EXT.import_context

This module customises the behaviour of the 
OpenGL.raw.GLX.EXT.import_context to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows multiple X clients to share an indirect
	rendering context.
	
	Additional convenience procedures to get the current Display*
	bound to a context as well as other context information are
	also added.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/import_context.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.EXT.import_context import *
from OpenGL.raw.GLX.EXT.import_context import _EXTENSION_NAME

def glInitImportContextEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_ANGLE_depth_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_ANGLE_depth_texture',error_checker=_errors._error_checker)
GL_DEPTH24_STENCIL8_OES=_C('GL_DEPTH24_STENCIL8_OES',0x88F0)
GL_DEPTH_COMPONENT=_C('GL_DEPTH_COMPONENT',0x1902)
GL_DEPTH_COMPONENT16=_C('GL_DEPTH_COMPONENT16',0x81A5)
GL_DEPTH_COMPONENT32_OES=_C('GL_DEPTH_COMPONENT32_OES',0x81A7)
GL_DEPTH_STENCIL_OES=_C('GL_DEPTH_STENCIL_OES',0x84F9)
GL_UNSIGNED_INT=_C('GL_UNSIGNED_INT',0x1405)
GL_UNSIGNED_INT_24_8_OES=_C('GL_UNSIGNED_INT_24_8_OES',0x84FA)
GL_UNSIGNED_SHORT=_C('GL_UNSIGNED_SHORT',0x1403)

